<?php

$styling_tab   = esc_html__( 'Styling', 'tm-moody' );
$spacing_tab   = esc_html__( 'Design Options', 'tm-moody' );
$separator_tab = esc_html__( 'Separator', 'tm-moody' );
$onepage_tab   = esc_html__( 'Onepage Scroll Options', 'tm-moody' );

vc_remove_param( 'vc_row', 'css' );
vc_remove_param( 'vc_row', 'gap' );

vc_add_params( 'vc_row', array(
	array(
		'heading'     => esc_html__( 'Layer Index', 'tm-moody' ),
		'description' => esc_html__( 'When content in row or row has negative margin then this controls layer ( z-index ) of row', 'tm-moody' ),
		'type'        => 'number',
		'param_name'  => 'layer_index',
		'min'         => 0,
		'max'         => 100,
		'step'        => 1,
	),
	array(
		'heading'     => esc_html__( 'Gutter', 'tm-moody' ),
		'type'        => 'number_responsive',
		'param_name'  => 'gutter',
		'min'         => 0,
		'max'         => 100,
		'step'        => 2,
		'suffix'      => 'px',
		'media_query' => array(
			'lg' => '',
			'md' => '',
			'sm' => '',
			'xs' => '',
		),
	),
	array(
		'group'        => $spacing_tab,
		'heading'      => esc_html__( 'Large Device Spacing', 'tm-moody' ),
		'type'         => 'spacing',
		'param_name'   => 'lg_spacing',
		'spacing_icon' => 'fa-desktop',
	),
	array(
		'group'        => $spacing_tab,
		'heading'      => esc_html__( 'Medium Device Spacing', 'tm-moody' ),
		'type'         => 'spacing',
		'param_name'   => 'md_spacing',
		'spacing_icon' => 'fa-tablet fa-rotate-270',
	),
	array(
		'group'        => $spacing_tab,
		'heading'      => esc_html__( 'Small Device Spacing', 'tm-moody' ),
		'type'         => 'spacing',
		'param_name'   => 'sm_spacing',
		'spacing_icon' => 'fa-tablet',
	),
	array(
		'group'        => $spacing_tab,
		'heading'      => esc_html__( 'Extra Small Spacing', 'tm-moody' ),
		'type'         => 'spacing',
		'param_name'   => 'xs_spacing',
		'spacing_icon' => 'fa-mobile',
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Border Color', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'border_color',
		'value'      => array(
			esc_html__( 'Primary Color', 'tm-moody' ) => 'primary',
			esc_html__( 'Custom Color', 'tm-moody' )  => 'custom',
		),
		'std'        => 'custom',
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Custom Border Color', 'tm-moody' ),
		'type'       => 'colorpicker',
		'param_name' => 'custom_border_color',
		'dependency' => array(
			'element' => 'border_color',
			'value'   => array( 'custom' ),
		),
		'std'        => '#eeeeee',
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Border Style', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'border_style',
		'value'      => array(
			esc_html__( 'Solid', 'tm-moody' )  => 'solid',
			esc_html__( 'Dashed', 'tm-moody' ) => 'dashed',
			esc_html__( 'Dotted', 'tm-moody' ) => 'dotted',
			esc_html__( 'Double', 'tm-moody' ) => 'double',
			esc_html__( 'Groove', 'tm-moody' ) => 'groove',
			esc_html__( 'Ridge', 'tm-moody' )  => 'ridge',
			esc_html__( 'Inset', 'tm-moody' )  => 'inset',
			esc_html__( 'Outset', 'tm-moody' ) => 'outset',
		),
		'std'        => 'solid',
	),
	array(
		'group'       => $styling_tab,
		'heading'     => esc_html__( 'Border Radius', 'tm-moody' ),
		'description' => esc_html__( 'Ex: 5px or 50%', 'tm-moody' ),
		'type'        => 'textfield',
		'param_name'  => 'border_radius',
	),
	array(
		'group'       => $styling_tab,
		'heading'     => esc_html__( 'Box Shadow', 'tm-moody' ),
		'description' => esc_html__( 'Ex: 0 20px 30px #ccc', 'tm-moody' ),
		'type'        => 'textfield',
		'param_name'  => 'box_shadow',
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Row Effect', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'effect',
		'value'      => array(
			esc_html__( 'None', 'tm-moody' )    => '',
			esc_html__( 'Firefly', 'tm-moody' ) => 'firefly',
		),
		'std'        => '',
	),
	array(
		'group'            => $styling_tab,
		'heading'          => esc_html__( 'Firefly Color', 'tm-moody' ),
		'type'             => 'colorpicker',
		'param_name'       => 'firefly_color',
		'dependency'       => array(
			'element' => 'effect',
			'value'   => array( 'firefly' ),
		),
		'std'              => '#fff',
		'edit_field_class' => 'vc_col-sm-3',
	),
	array(
		'group'            => $styling_tab,
		'heading'          => esc_html__( 'Firely Total', 'tm-moody' ),
		'type'             => 'number',
		'param_name'       => 'firefly_total',
		'value'            => 100,
		'min'              => 0,
		'max'              => 100,
		'step'             => 1,
		'suffix'           => '%',
		'std'              => 30,
		'dependency'       => array(
			'element' => 'effect',
			'value'   => array( 'firefly' ),
		),
		'edit_field_class' => 'vc_col-sm-3',
	),
	array(
		'group'            => $styling_tab,
		'heading'          => esc_html__( 'Firely Min Width', 'tm-moody' ),
		'type'             => 'number',
		'param_name'       => 'firefly_min_size',
		'value'            => 100,
		'min'              => 0,
		'max'              => 100,
		'step'             => 1,
		'suffix'           => '%',
		'std'              => 1,
		'dependency'       => array(
			'element' => 'effect',
			'value'   => array( 'firefly' ),
		),
		'edit_field_class' => 'vc_col-sm-3',
	),
	array(
		'group'            => $styling_tab,
		'heading'          => esc_html__( 'Firely Max Width', 'tm-moody' ),
		'type'             => 'number',
		'param_name'       => 'firefly_max_size',
		'value'            => 100,
		'min'              => 0,
		'max'              => 100,
		'step'             => 1,
		'suffix'           => '%',
		'std'              => 3,
		'dependency'       => array(
			'element' => 'effect',
			'value'   => array( 'firefly' ),
		),
		'edit_field_class' => 'vc_col-sm-3',
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Background Color', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'background_color',
		'value'      => array(
			esc_html__( 'None', 'tm-moody' )            => '',
			esc_html__( 'Primary Color', 'tm-moody' )   => 'primary',
			esc_html__( 'Secondary Color', 'tm-moody' ) => 'secondary',
			esc_html__( 'Custom Color', 'tm-moody' )    => 'custom',
			esc_html__( 'Gradient Color', 'tm-moody' )  => 'gradient',
		),
		'std'        => '',
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Custom Background Color', 'tm-moody' ),
		'type'       => 'colorpicker',
		'param_name' => 'custom_background_color',
		'dependency' => array(
			'element' => 'background_color',
			'value'   => array( 'custom' ),
		),
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Background Gradient', 'tm-moody' ),
		'type'       => 'gradient',
		'param_name' => 'background_gradient',
		'dependency' => array(
			'element' => 'background_color',
			'value'   => array( 'gradient' ),
		),
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Background Image', 'tm-moody' ),
		'type'       => 'attach_image',
		'param_name' => 'background_image',
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Hide Background Image', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'hide_background_image',
		'value'      => array(
			esc_html__( 'Always show', 'tm-moody' )             => '',
			esc_html__( 'Medium Device Down', 'tm-moody' )      => 'md',
			esc_html__( 'Small Device Down', 'tm-moody' )       => 'sm',
			esc_html__( 'Extra Small Device Down', 'tm-moody' ) => 'xs',
		),
		'std'        => '',
		'dependency' => array(
			'element'   => 'background_image',
			'not_empty' => true,
		),
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Background Repeat', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'background_repeat',
		'value'      => array(
			esc_html__( 'No repeat', 'tm-moody' )         => 'no-repeat',
			esc_html__( 'Tile', 'tm-moody' )              => 'repeat',
			esc_html__( 'Tile Horizontally', 'tm-moody' ) => 'repeat-x',
			esc_html__( 'Tile Vertically', 'tm-moody' )   => 'repeat-y',
		),
		'std'        => 'no-repeat',
		'dependency' => array(
			'element'   => 'background_image',
			'not_empty' => true,
		),
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Background Size', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'background_size',
		'value'      => array(
			esc_html__( 'Auto', 'tm-moody' )    => 'auto',
			esc_html__( 'Cover', 'tm-moody' )   => 'cover',
			esc_html__( 'Contain', 'tm-moody' ) => 'contain',
			esc_html__( 'Manual', 'tm-moody' )  => 'manual',
		),
		'std'        => 'cover',
		'dependency' => array(
			'element'   => 'background_image',
			'not_empty' => true,
		),
	),
	array(
		'group'       => $styling_tab,
		'heading'     => esc_html__( 'Background Size (Manual Setting)', 'tm-moody' ),
		'description' => esc_html__( 'Ex: 50% 100%', 'tm-moody' ),
		'type'        => 'textfield',
		'param_name'  => 'background_size_manual',
		'dependency'  => array(
			'element' => 'background_size',
			'value'   => 'manual',
		),
	),
	array(
		'group'       => $styling_tab,
		'heading'     => esc_html__( 'Background Position', 'tm-moody' ),
		'description' => esc_html__( 'Ex: left center', 'tm-moody' ),
		'type'        => 'textfield',
		'param_name'  => 'background_position',
		'dependency'  => array(
			'element'   => 'background_image',
			'not_empty' => true,
		),
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Scroll Effect', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'background_attachment',
		'value'      => array(
			esc_html__( 'Move with the content', 'tm-moody' ) => 'scroll',
			esc_html__( 'Fixed at its position', 'tm-moody' ) => 'fixed',
			esc_html__( 'Marque', 'tm-moody' )                => 'marque',
		),
		'std'        => 'scroll',
		'dependency' => array(
			'element'   => 'background_image',
			'not_empty' => true,
		),
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Marque Direction', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'marque_direction',
		'value'      => array(
			esc_html__( 'To Left', 'tm-moody' )  => 'to-left',
			esc_html__( 'To Right', 'tm-moody' ) => 'to-right',
		),
		'std'        => 'to-right',
		'dependency' => array(
			'element' => 'background_attachment',
			'value'   => 'marque',
		),
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Marque Pause On Hover.', 'tm-moody' ),
		'type'       => 'checkbox',
		'param_name' => 'marque_pause_on_hover',
		'value'      => array(
			esc_html__( 'Yes', 'tm-moody' ) => '1',
		),
		'dependency' => array(
			'element' => 'background_attachment',
			'value'   => 'marque',
		),
	),
	array(
		'group'       => $styling_tab,
		'heading'     => esc_html__( 'Background Overlay', 'tm-moody' ),
		'description' => esc_html__( 'Choose an overlay background color.', 'tm-moody' ),
		'type'        => 'dropdown',
		'param_name'  => 'overlay_background',
		'value'       => array(
			esc_html__( 'None', 'tm-moody' )            => '',
			esc_html__( 'Primary Color', 'tm-moody' )   => 'primary',
			esc_html__( 'Secondary Color', 'tm-moody' ) => 'secondary',
			esc_html__( 'Custom Color', 'tm-moody' )    => 'overlay_custom_background',
		),
	),
	array(
		'group'       => $styling_tab,
		'heading'     => esc_html__( 'Custom Background Overlay', 'tm-moody' ),
		'description' => esc_html__( 'Choose an custom background color overlay.', 'tm-moody' ),
		'type'        => 'colorpicker',
		'param_name'  => 'overlay_custom_background',
		'std'         => '#000000',
		'dependency'  => array( 'element' => 'overlay_background', 'value' => array( 'overlay_custom_background' ) ),
	),
	array(
		'group'      => $styling_tab,
		'heading'    => esc_html__( 'Opacity', 'tm-moody' ),
		'type'       => 'number',
		'param_name' => 'overlay_opacity',
		'value'      => 100,
		'min'        => 0,
		'max'        => 100,
		'step'       => 1,
		'suffix'     => '%',
		'std'        => 80,
		'dependency' => array(
			'element'   => 'overlay_background',
			'not_empty' => true,
		),
	),
	array(
		'group'      => $separator_tab,
		'heading'    => esc_html__( 'Type', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'separator_type',
		'value'      => array(
			esc_html__( 'None', 'tm-moody' )         => '',
			esc_html__( 'Triangle', 'tm-moody' )     => 'triangle',
			esc_html__( 'Big Triangle', 'tm-moody' ) => 'big_triangle',
			esc_html__( 'Half Circle', 'tm-moody' )  => 'half_circle',
		),
		'std'        => '',
	),
	array(
		'group'      => $separator_tab,
		'heading'    => esc_html__( 'Direction', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'separator_direction',
		'value'      => array(
			esc_html__( 'Up', 'tm-moody' )   => 'up',
			esc_html__( 'Down', 'tm-moody' ) => 'down',
			esc_html__( 'Both', 'tm-moody' ) => 'both',
		),
		'std'        => 'down',
		'dependency' => array(
			'element'   => 'separator_type',
			'not_empty' => true,
		),
	),
	array(
		'group'      => $separator_tab,
		'heading'    => esc_html__( 'Separator Color 1', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'separator_color_1',
		'value'      => array(
			esc_html__( 'Primary Color', 'tm-moody' ) => 'primary_color',
			esc_html__( 'Custom Color', 'tm-moody' )  => 'custom',
		),
		'std'        => 'custom',
		'dependency' => array(
			'element'   => 'separator_type',
			'not_empty' => true,
		),
	),
	array(
		'group'      => $separator_tab,
		'heading'    => esc_html__( 'Custom Separator Color 1', 'tm-moody' ),
		'type'       => 'colorpicker',
		'param_name' => 'custom_separator_color_1',
		'dependency' => array(
			'element' => 'separator_color_1',
			'value'   => array( 'custom' ),
		),
		'std'        => '#fff',
	),
	array(
		'group'      => $separator_tab,
		'heading'    => esc_html__( 'Separator Color 2', 'tm-moody' ),
		'type'       => 'dropdown',
		'param_name' => 'separator_color_2',
		'value'      => array(
			esc_html__( 'Transparent', 'tm-moody' )   => '',
			esc_html__( 'Primary Color', 'tm-moody' ) => 'primary_color',
			esc_html__( 'Custom Color', 'tm-moody' )  => 'custom',
		),
		'std'        => 'primary_color',
		'dependency' => array(
			'element'   => 'separator_type',
			'not_empty' => true,
		),
	),
	array(
		'group'      => $separator_tab,
		'heading'    => esc_html__( 'Custom Separator Color 2', 'tm-moody' ),
		'type'       => 'colorpicker',
		'param_name' => 'custom_separator_color_2',
		'dependency' => array(
			'element' => 'separator_color_2',
			'value'   => array( 'custom' ),
		),
		'std'        => '#000',
	),
	array(
		'group'       => $onepage_tab,
		'heading'     => esc_html__( 'Skin', 'tm-moody' ),
		'description' => esc_html__( 'Controls the skin of pagination when view this section.', 'tm-moody' ),
		'type'        => 'dropdown',
		'param_name'  => 'onepage_skin',
		'value'       => array(
			esc_html__( 'Dark', 'tm-moody' )  => 'dark',
			esc_html__( 'Light', 'tm-moody' ) => 'light',
		),
		'std'         => 'dark',
	),
	array(
		'group'       => $onepage_tab,
		'heading'     => esc_html__( 'Title', 'tm-moody' ),
		'description' => esc_html__( 'Controls the text of this section.', 'tm-moody' ),
		'type'        => 'textfield',
		'param_name'  => 'onepage_title',
	),
	array(
		'group'       => $onepage_tab,
		'heading'     => esc_html__( 'Anchor', 'tm-moody' ),
		'description' => esc_html__( 'Add the unique anchor name. The anchor can used for anchor navigation in menu.', 'tm-moody' ),
		'type'        => 'textfield',
		'param_name'  => 'onepage_anchor',
	),
) );
